@@ -14,7 +14,7 @@ def do_post_req(mytestcase, ep, headers, payload):
     """
     self = mytestcase
     try:
-        # print("--- Starting POST request to {}".format(ep))
+        print("--- Starting POST request to {}".format(ep))
         sleep(0.05)
         r = self.client.open(
             ep,
@@ -35,7 +35,7 @@ def do_get_req(mytestcase, ep, headers):
     """
     self = mytestcase
     try:
-        # print("--- Starting GET request to {}".format(ep))
+        print("--- Starting GET request to {}".format(ep))
         sleep(0.05)
         r = self.client.open(
             ep,
@@ -55,7 +55,7 @@ def do_head_req(mytestcase, ep, headers):
     """
     self = mytestcase
     try:
-        # print("--- Starting HEAD request to {}".format(ep))
+        print("--- Starting HEAD request to {}".format(ep))
         sleep(0.05)
         r = self.client.open(
             ep,
@@ -75,7 +75,7 @@ def do_delete_req(mytestcase, ep, headers):
     """
     self = mytestcase
     try:
-        # print("--- Starting DELETE request to {}".format(ep))
+        print("--- Starting DELETE request to {}".format(ep))
         sleep(0.05)
         r = self.client.open(
             ep,
@@ -95,7 +95,7 @@ def do_put_req(mytestcase, ep, headers, payload):
     """
     self = mytestcase
     try:
-        # print("--- Starting POST request to {}".format(ep))
+        print("--- Starting POST request to {}".format(ep))
         sleep(0.05)
         r = self.client.open(
             ep,
@@ -205,7 +205,7 @@ def generate_payloads_from_request_vars(request_vars: dict) -> List[Dict[str, st
                 for param_key, param_value in request_vars.items():
                     data_type = param_value.get("type", "")
                     happy_day_string = get_happyday_pattern(data_type)
-
+                    # FIXME: Why loop twice over the same list and then only do something when both indices match?
                     if param_key == request_key:
                         # fuzz both data type and fuzz type
                         if fuzz_type == "int" or data_type == "int" or data_type == "number":
